<?php
/**
 * magpoint functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package magpoint
 */

if ( ! defined( 'MAGPOINT_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'MAGPOINT_VERSION', '1.0.2' );
}

if ( ! function_exists( 'magpoint_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function magpoint_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on magpoint, use a find and replace
		 * to change 'magpoint' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'magpoint', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
			'top'    => __( 'Primary Menu', 'magpoint' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'magpoint_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'magpoint_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function magpoint_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'magpoint_content_width', 640 );
}
add_action( 'after_setup_theme', 'magpoint_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function magpoint_widgets_init() {
	register_sidebar(
		array(
			'name'          => __( 'Blog Sidebar', 'magpoint' ),
			'id'            => 'sidebar-main',
			'description'   => __( 'Add widgets here.', 'magpoint' ),
			'before_widget' => '<div id="%1$s" class="widget sidebar-post sidebar %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="sidebar-title"><h3 class="title mb-20">',
			'after_title'   => '</h3></div>',
		)
	);
	register_sidebar(
		array(
			'name'          => __( 'Footer Widgets', 'magpoint' ),
			'id'            => 'footer-widgets',
			'description'   => __( 'Add widgets here.', 'magpoint' ),
			'before_widget' => '<div class="%2$s footer-widget col-md-3 col-sm-6 col-xs-12">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="sidebar-title"><h3 class="widget-title mb-20">',
			'after_title'   => '</h3></div>',
		)
	);
}
add_action( 'widgets_init', 'magpoint_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function magpoint_scripts() {
	wp_enqueue_style('bootstrap-css', get_template_directory_uri() . '/assets/css/bootstrap.css');
	wp_enqueue_style('font-awesome-css', get_template_directory_uri() . '/assets/css/font-awesome.css');
	wp_enqueue_style('magpoint-meanmenu-css', get_template_directory_uri() . '/assets/css/magpoint-meanmenu.css');
	wp_enqueue_style('magpoint-responsive-css', get_template_directory_uri() . '/assets/css/magpoint-responsive.css');
	wp_enqueue_style('magpoint-custom-css', get_template_directory_uri() . '/assets/css/magpoint-custom.css');


	wp_enqueue_style( 'magpoint-style', get_stylesheet_uri(), array(), MAGPOINT_VERSION );
	wp_style_add_data( 'magpoint-style', 'rtl', 'replace' );

	wp_enqueue_script( 'magpoint-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), MAGPOINT_VERSION, true );

	wp_enqueue_script( 'popper-js', get_template_directory_uri() . '/assets/js/popper.js',array('jquery'), MAGPOINT_VERSION, true );
	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/assets/js/bootstrap.js',array(), MAGPOINT_VERSION, true );

	wp_enqueue_script( 'magpoint-main-js', get_template_directory_uri() . '/assets/js/main.js',array(), MAGPOINT_VERSION, true );

	wp_enqueue_script( 'magpoint-global-js', get_template_directory_uri() . '/assets/js/global.js',array(), MAGPOINT_VERSION, true );
	
	wp_enqueue_script( 'magpoint-menu-modal', get_template_directory_uri() . '/assets/js/menu-accessibility.js',array(), MAGPOINT_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'magpoint_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/controls.php';

require get_template_directory() . '/inc/customizer.php';